BidmadSplashAdData class

Constructors

BidmadSplashAdData({required String imageUrl, required String impressionUrl, required String splashType, String? endDate})
BidmadSplashAdData.fromMap(Map<Object?, Object?> map)
factory

Properties

endDate → String?
final
hashCode → int
The hash code for this object.
no setterinherited
imageUrl → String
final
impressionUrl → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splashType → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited